package com.lhcx.service;

import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.List;

import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.lhcx.c3p0.C3P0Util;

@Path("/pay")
public class PaymentService {
	
	/**
	 * 应缴金额查询
	 * @param jsonParams：{"getsure_unit_no": "512090010", "aae135": "511081198110190286", "aac003": "003"}
	 * @return[
			    {
			        "msgno": "0000",
			        "msg": [
			            {
			                "ybh": "511081198110190286",
			                "dwmc": "四川省资阳强制隔离戒毒所（大堰）",
			                "da_id": "512099020031",
			                "dwbh": "511002208",
			                "jfze": "6821.6",
			                "dwjfje": "5859.2",
			                "xm": "黄燕",
			                "cbxz": "城镇职工医保",
			                "gzzt": "在职",
			                "grjfje": "962.4",
			                "sjgrjfje": "802",
			                "sjdwjfje": "3109.7",
			                "sjjfze": "3911.7"
			            }
			        ]
			    }
			]
	 * @throws UnsupportedEncodingException 
	 */
	@POST
    @Path("payableQuery")
	@Produces("text/plain")
	public String payableQuery(String params) throws UnsupportedEncodingException {
		JSONObject parObj = JSONObject.parseObject(params);
		String getsureNnitNo = parObj.getString("getsure_unit_no");
		String aae135 = parObj.getString("aae135");
		String aac003 = parObj.getString("aac003");
        
        List<String> inputParam = new ArrayList<String>();
        inputParam.add(getsureNnitNo);
        inputParam.add(aae135);
        inputParam.add(aac003);
        String strPro = "{call up_query(?,?,?,?)}";
        String sqlStr=C3P0Util.oracleExcePro(strPro, inputParam);
        String resStr = C3P0Util.oracleQuery(sqlStr);
        JSONArray resArr = JSONObject.parseArray(resStr);
        JSONArray jsonArray = resArr.getJSONArray(0);
        if(jsonArray.isEmpty()){
        	return String.format("[{\"msgno\":\"%s\",\"msg\":\"%s\"}]","9999","未查询到相关数据！");
        }
        JSONObject infoObj = jsonArray.getJSONObject(0);
        if("9999".equals(infoObj.getString("msgno"))){
			return String.format("[%s]", infoObj.toJSONString());
        }
        
        String result=String.format("[{\"msgno\":\"%s\",\"msg\":[%s]}]","0000",infoObj.toJSONString());
        return result;
    } 
	
	/**
	 * 上账
	 * @param jsonParams：{
	 * 						"da_id":"",//档案号
							"ATM_no":"",//一体机唯一编号
							"trade_no":"",//交易号流水号
						    "money":"",//上账金额
						  }
	 * @return：[{
			        "msgno": "0000",//状态0000成功9999失败
			        "msg":"上账成功"//或者失败原因
			    }]
	 */
	@POST
    @Path("account")
    @Produces("text/plain")
	public String account(String params) {
		JSONObject parObj = JSONObject.parseObject(params);
		String daId = parObj.getString("da_id");
		String atmNo = parObj.getString("ATM_no");
		String tradeNo = parObj.getString("trade_no");
		String money = parObj.getString("money");
		List<String> inputParam = new ArrayList<String>();
        inputParam.add(daId);
        inputParam.add(atmNo);
        inputParam.add(tradeNo);
        inputParam.add(money);
        String strPro = "{call Up_Person_Yes(?,?,?,?,?)}";
        String sqlStr = C3P0Util.oracleExcePro(strPro, inputParam);
        String resStr = C3P0Util.oracleQuery(sqlStr);
		return String.format("[%s]", resStr);
	} 
	
	/**
	 * 上账回滚
	 * @param jsonParams：{
							"da_id":"",//档案号
							"ATM_no":"",//一体机唯一编号
							"trade_no":"",//上账交易的流水号
							"rollback_no":""//回滚交易的流水号
						   }
	 * @return:[{
			        "msgno": "0000",//状态0000成功9999失败
			        "msg":"上账回滚成功"//或者失败原因
			    }]
	 */
	@POST
    @Path("accountRollback")
    @Produces("text/plain")
	public String accountRollback(String params) {
		JSONObject parObj = JSONObject.parseObject(params);
		String daId = parObj.getString("da_id");
		String atmNo = parObj.getString("ATM_no");
		String tradeNo = parObj.getString("trade_no");
		String rollbackNo = parObj.getString("rollback_no");
		List<String> inputParam = new ArrayList<String>();
        inputParam.add(daId);
        inputParam.add(atmNo);
        inputParam.add(tradeNo);
        inputParam.add(rollbackNo);
        String strPro = "{call Up_rollback_Yes(?,?,?,?,?)}";
        String sqlStr = C3P0Util.oracleExcePro(strPro, inputParam);
        String resStr = C3P0Util.oracleQuery(sqlStr);
        
        return String.format("[%s]", resStr);
	} 
}
